local mod = ...



-- Building Asset Processor -------------------------------------------------------------------------------------
mod:registerAssetProcessor("models/Cobbler1.fbx", { DataType = "BUILDING_ASSET_PROCESSOR" })



-- Asset -------------------------------------------------------------------------------------
mod:registerAssetId("models/Cobbler1.fbx/Prefab/Cobbler.Part", "PREFAB_LIVESTOCKFARM_COBBLER")
mod:registerAssetId("models/Cobbler1.fbx/Prefab/Cobbler.Part.Constr", "PREFAB_LIVESTOCKFARM_COBBLER_CONSTR")



-- Grounding -------------------------------------------------------------------------------------
mod:registerPrefabComponent("models/Cobbler1.fbx/Prefab/Cobbler.Part/Door.001", {DataType = "COMP_GROUNDED"})



-- Job -------------------------------------------------------------------------------------
mod:registerAsset({
	DataType = "JOB",
	Id = "JOB_LIVESTOCKFARM_COBBLER",
	JobName = "JOB_LIVESTOCKFARM_COBBLER_NAME",
	JobDescription = "JOB_LIVESTOCKFARM_COBBLER_DESC",
	IsLockedByDefault = false,
	DefaultBehavior = "BEHAVIOR_WORK",
    ProductionDelay = 30.0, -- default 30
	AssetJobProgression = "DEFAULT_JOB_PROGRESSION",
	CharacterSetup = {
		DataType = "CHARACTER_SETUP",
        RightHandObject = {
            Model = "PREFAB_TOOL_BLACKSMITH_HAMMER",
        },
		IdleAnimation = "MIXING",
	}
})

mod:overrideAsset({
    Id = "NEWCOMER",
    CompatibleJobList = {
        Action = "APPEND",
        "JOB_LIVESTOCKFARM_COBBLER"
    }
})

mod:overrideAsset({
    Id = "SERF",
    CompatibleJobList = {
        Action = "APPEND",
        "JOB_LIVESTOCKFARM_COBBLER"
    }
})

mod:overrideAsset({
    Id = "COMMONER",
    CompatibleJobList = {
        Action = "APPEND",
        "JOB_LIVESTOCKFARM_COBBLER"
    }
})

-- mod:overrideAsset({
--     Id = "CITIZEN",
--     CompatibleJobList = {
--         Action = "APPEND",
--         "CHANDLER_JOB"
--     }
-- })



-- Building Function -------------------------------------------------------------------------------------
mod:registerAsset({
    DataType = "BUILDING_FUNCTION_WORKPLACE",
	Id = "BUILDING_FUNCTION_LIVESTOCKFARM_COBBLER",
    Name = "BUILDING_FUNCTION_LIVESTOCKFARM_COBBLER_NAME",
    WorkerCapacity = 1,
    RelatedJob = {
        Job = "JOB_LIVESTOCKFARM_COBBLER",
        Behavior = "BEHAVIOR_WORK",
    },
	InputInventoryCapacity = {
		{ Resource = "LEATHER", Quantity = 25 },
		-- { Resource = "WOOD", Quantity = 25 },
	},
    ResourceListNeeded = {
		{ Resource = "LEATHER", Quantity = 1 },
		-- { Resource = "WOOD", Quantity = 1 },
	},
	ResourceProduced = {
		{ Resource = "RESOURCE_SHOES", Quantity = 1 },
	},
})



-- Building: ------------------------------------------------------------------------------------
mod:registerAsset({
	DataType = "BUILDING",
	Id = "BUILDING_LIVESTOCKFARM_COBBLER",
	Name = "BUILDING_LIVESTOCKFARM_COBBLER_NAME",
	Description = "BUILDING_LIVESTOCKFARM_COBBLER_DESC",
	BuildingType = "GOODS_PRODUCTION",
	AssetCoreBuildingPart = "BUILDING_PART_LIVESTOCKFARM_COBBLER",
	VillagerRequired = { Status = "COMMONER", Quantity = 1 },
})



-- Building Part -------------------------------------------------------------------------------------
mod:registerAsset({
	DataType = "BUILDING_PART",
	Id = "BUILDING_PART_LIVESTOCKFARM_COBBLER",
	Name = "BUILDING_PART_LIVESTOCKFARM_COBBLER_NAME",
	ConstructorData = {
		DataType = "BUILDING_CONSTRUCTOR_DEFAULT",
		CoreObjectPrefab = "PREFAB_LIVESTOCKFARM_COBBLER",
        MiniatureConfig = {
            ClipUnderGround = true,
            GroupHeight = 0.0,
            CameraPosition = { 0, 4, -21 },
            OrientationOffset = 0.0,
            CameraPitchOffset = 0.0
        },
	},
	ConstructionVisual = "PREFAB_LIVESTOCKFARM_COBBLER_CONSTR",
	BuildingZone = { 
        ZoneEntryList = {
            {
                Polygon = polygon.createRectangle( {3.5, 5.25}, {0.0, 0.0} ),
                Type = { DEFAULT = true, NAVIGABLE = true, GRASS_CLEAR = true },
			},
            {
                Polygon = polygon.createRectangle( {5.25, 3.5}, {0.0, 0.0} ),
                Type = { DEFAULT = true, NAVIGABLE = true, GRASS_CLEAR = true },
			},
		},
	},
	AssetBuildingFunction = "BUILDING_FUNCTION_LIVESTOCKFARM_COBBLER",
	Cost = {
		BuildRightTaxes = {	{ Resource = "GOLD", Quantity = 25 } },
		UpkeepCost = { { Resource = "GOLD", Quantity = 10 } },
		ResourceNeededList = {
            {
                { Resource = "STONE", Quantity = 10 },
            },
            {
                { Resource = "WOOD", Quantity = 14 },
                { Resource = "PLANK", Quantity = 18 },
            },
            {
                { Resource = "TOOL", Quantity = 4 },
            },
		}
	},
})



